**Example 1: 示例**



Input: 

```
tccli tcb CheckTcbService --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "Initialized": false,
        "RequestId": "51a33e48-a808-4fe7-8c02-4e7be5245351"
    }
}
```

